import {
  ButtonBase,
  CardContent,
  Stack,
  Card,
  CardActions,
  Tooltip,
} from "@mui/material";
import Link from "next/link";
import Image from "next/image";
import ProductPriceRenderer from "./components/ProductPriceRenderer";
import DiscountRenderer from "./components/DiscountRenderer";

const ProductCard = ({ item }) => {
  const {
    name,
    // score,
    desc,
    image,
    price,
    finalPrice,
    discountedPrice,
    discountPercent,
    discountEndTime,
    hasDiscount,
    url,
  } = item;

  return (
    <Link href={url} className="w-full">
      <ButtonBase
        sx={{
          width: "100%",
          height: "328px",
          backgroundColor: "white",
          borderRadius: "16px",
        }}
        className="shadow-base"
      >
        <Card
          sx={{
            boxShadow:"none",
            width: "100%",
            height: "100%",
            display: "flex",
            flexDirection: "column",
            justifyContent: "space-between",
          }}
        >
          <CardContent
            sx={{ display: "flex", flex: 1 }}
            className="border-b border-border-main"
          >
            <Stack sx={{ width: "100%", gap: "8px" }}>
              <div className="w-full h-[94px] shrink-0 rounded-md overflow-hidden bg-background-tertiary">
                {image && image.url && image.url !== "" && (
                  <Image
                    src={image.url}
                    alt={image.alt}
                    title={image.title}
                    width={"0"}
                    height={"0"}
                    sizes="100vw"
                    className="w-full h-[94px] object-cover"
                  />
                )}
              </div>
              {/* <div className="w-full flex items-center justify-between">
                <p className="text-xs">1320 نفر این محصول را تهیه کرده اند</p>
                <div className="flex items-center gap-1 flex-nowrap">
                  <Star1 size="14" color="#EAB208" variant="Bold" />
                  <p className="text-xs font-bold">5</p>
                </div>
              </div> */}
              <h2 className="text-start  text-sm leading-8 font-bold">{name}</h2>
              <Tooltip title={desc}>
                <h3 className="text-start text-xs leading-6 line-clamp-2  text-text-third">
                  {desc}
                </h3>
              </Tooltip>
            </Stack>
          </CardContent>
          <CardActions className="h-12 max-h-12 shrink-0">
            <div className="w-full flex flex-row-reverse justify-between ">
              <ProductPriceRenderer
                hasDiscound={hasDiscount}
                price={price}
                discountedPrice={discountedPrice}
                discountPercent={discountPercent}
                finalPrice={finalPrice}
              />
              <DiscountRenderer
                hasDiscount={hasDiscount}
                discountEndTime={discountEndTime}
              />
            </div>
          </CardActions>
        </Card>
      </ButtonBase>
    </Link>
  );
};

export default ProductCard;
